/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Color;
import java.awt.Graphics2D;



import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;

/**
 * This test renders filled shapes using linear gradient paint.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class LinearGradientPaint extends GfxTest
{
    // numbers ranging from 0.0 to 1.0 specifying the distribution of colors along the gradient
    private static final float[] SpectrumFractions = { 0.0f, 1.0f/6, 2.0f/6, 3.0f/6, 4.0f/6, 5.0f/6, 1.0f };

    // array of colors corresponding to each fractional value
    private static final Color[] SpectrumColors = {
        Color.MAGENTA,
        Color.BLUE,
        Color.CYAN,
        Color.GREEN,
        Color.YELLOW,
        Color.ORANGE,
        Color.RED
    };

    /**
     * Test if circle drawn by graphics.drawOval() is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleLinearGradientEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the circle
        CommonShapesRenderer.drawCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if rectangle is rendered correctly.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleLinearGradientEmptyFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // draw the rectangle
        CommonShapesRenderer.drawRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }
    
    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Horizontal linear gradient paint is used for filling this circle using
     * whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleHorizontalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Vertical linear gradient paint is used for filling this circle using
     * whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleVerticalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Diagonal linear gradient paint is used for filling this circle using
     * whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleDiagonalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Horizontal linear gradient paint is used for filling this rectangle using
     * whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleHorizontalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setHorizontalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Vertical linear gradient paint is used for filling this rectangle using
     * whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleVerticalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setVerticalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Diagonal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalLinearGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Diagonal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalLinearGradientFillPositiveOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Diagonal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalLinearGradientFillPositiveOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Diagonal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalLinearGradientFillNegativeOffset1(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, - image.getWidth() / 16);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Diagonal gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalLinearGradientFillNegativeOffset2(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, - image.getWidth() / 6);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly. Diagonal linear gradient
     * paint is used for filling this rectangle using whole color spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleDiagonalColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setDiagonalLinearGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args graphics test configuration
     */
    public static void main(String[] args)
    {
        new LinearGradientPaint().runTestSuite(args);
    }
}
